##  Portal Permissions
You can modify permissions for all portals for non-admin roles in the User Roles and Permissions section of the administration area. For more information, see [Role-Based Permissions](https://help.sap.com/docs/leanix/ea/user-roles-and-permissions?locale=en-US&state=PRODUCTION&version=CLOUD#loio275def827a4410149362f3672c614956__role-based_permissions).
